DECLARE SUB InitDataArrays ()
SuntanProgram:
DIM SHARED F1$
DIM SHARED OZ(20), FS(20), ACTS(20)
CALL InitDataArrays: 'Initalize data arrays

MeasurementSystem:
Metric = 0
MS = 0
CLS
PRINT "Please choose the measurement system to be used."
PRINT
PRINT "1. Customary"
PRINT "2. Metric"
PRINT
INPUT MS
IF MS = 1 THEN Metric = 0
IF MS = 2 THEN Metric = 1
IF (MS > 2) OR (MS < 1) THEN GOTO MeasurementSystem

InputData:
CLS
INPUT "Latitude in degrees (Washington, D.C. = 39)"; L
LA = L / 57.296
INPUT "Month (1-12)"; M
70 INPUT "Hours from local noon"; T
T = ABS(T)
DS = .408 * SIN(.523 * (M - 3.7)): ' Decl of Sun (radians)
HA = .262 * T: ' Hour angle of Sun (radians)
CZ = SIN(LA) * SIN(DS) + COS(LA) * COS(DS) * COS(HA)
IF CZ <= 0 THEN GOTO 70
ZS = ATN(SQR(1 - CZ ^ 2) / CZ): ' Sun's zenith dist. (rad.)
IF Metric THEN
        INPUT "Height above sea level (meters)"; HH
        HH = HH * .3048
ELSE
        INPUT "Height above sea level (feet)"; HH
END IF
H = HH / 3280
INPUT "Aerosol extinction (V mag/airmass) (sea level  0.2)"; KK
BE = KK / 2.36
INPUT "Surface albedo (%) (dry beach  12)"; S1
SA = S1 / 100
INPUT "Exposure time (seconds)"; ET
ZP = ZS
SS = 0
INPUT "Percentage of UV light blocked by clothes, lotion, etc."; T9
TW = 1 - T9 / 100
INPUT "Percentage of sky that is clear"; F1a
F1 = F1a / 100
INPUT "Percentage of ground in sunlight"; F2a
F2 = F2a / 100
INPUT "Is Sun being shaded (Y/N)"; SH$
IF UCASE$(LEFT$(SH$, 1)) = "Y" THEN
        SH = 0
ELSE
        SH = 1
END IF
INPUT "Normalization for skin color (Avg Caucasian = 1) (Avg Black = .1)"; N
RE = 6378
INPUT "Percentage of ozone lost in area"; OL
HO = 23
HG = 8.2
HA = 1.5
DS = 1

ThinknessOzoneLayer:
RA = 30 * (M - 3.7) / 57.296
DOZ = (1 - OL / 100) * (3 + .4 * (LA * COS(RA) - COS(3 * LA)))

Airmass:
XO = (1 - (SIN(ZS) / (1 + ((HO - H) / RE))) ^ 2) ^ -.5
XG = 1 / (COS(ZS) + .01 * SQR(HG) * EXP(-30 * COS(ZS) / SQR(HG)))
XA = 1 / (COS(ZS) + .01 * SQR(HA) * EXP(-30 * COS(ZS) / SQR(HA)))

DoForEachWavelength:
CLS
PRINT "Wavelength     Ozone     Air     Action     Dose"
PRINT "(angstroms)     trans.   trans.   spectr.         "
ED = 0
FOR J = 1 TO 20
        W = .275 + K * .005: 'Wavelength (microns)
        '
        ' Brightness of sunlight, diffuse sky light, and ground light
        KO = OZ(J) * (DOZ / 3)
        KG = .0107 * EXP(-H / HG) * (W ^ -4)
        KA = BE * (W ^ -1.3)
        OT = 10 ^ (-.4 * KO ^ 2)
        TA = 10 ^ (-.4 * (KG ^ 2 + KA ^ 2))
        D = .5 * (COS(ZS) ^ .33)
        ISS = FS(J) * OT * TA * TW * SH * COS(SS) * DS ^ -2
        ID = FS(J) * OT * (1 - TA) * D
        ID = ID * TA * SA + ID
        ID = FS(J) * OT * ((1 - TA) ^ 2) * SA * (D ^ 2) + ID
        ID = ID * TW * F1 * (COS(ZS / 2) ^ 2) * (DS ^ -2)
        IG = FS(J) * OT * SA * (TA + D * (1 - TA))
        IG = IG * TW * F2 * (SIN(ZS / 2) ^ 2) * DS ^ -2
        I = ISS + ID = IG: ' Total flux on skin (erg/cm^2/sec/A)
        '
        ' Find effective dose by numerical integration.
        ' The "minimum erythema dose" at 2900A is 2.3E6 erg/cm^2 (Parrish).
        '
        EF = I * ET * (ACTS(J) * N) * 50 / 2300000!
        ED = ED + EF
        PRINT USING F1$; W * 10000; OT; TA; ACTS(J); EF
NEXT J

ReportResult:
CLS
PRINT
PRINT USING "Total effective dose: ##.###"; ED
PRINT USING "    (exposure time ##.## hr)"; ET / 3600
PRINT USING "Butning starts after ##.## hr"; ET / (3600 * ED)

END


DataStatements:
'
' OZ array (ozone effect)
DATA 34, 25, 18, 9, 3.2, 1.8, .9, .46, .24, .17
DATA .06, .05, .02, .01, .002, .001, 0, 0, 0, 0
'
' FS array (solar flux at 1 A.U. in erg/cm^2/sec/A)
DATA 24, 31, 38, 45, 52, 58, 64, 70, 75, 79
DATA 83, 87, 91, 93, 95, 97, 99, 104, 107, 104
'
' ACTS arrays (action spectrum, McKinley & Diffey)
DATA 1, 1, 1, 1, .65, .22, .074, .025, .0086, .003
DATA .0014, .0012, .00097, .00081, .00068, .00057
DATA .00048, .0004, .00034, .00029

SUB InitDataArrays
        ' Set up data arrays
        '
        F1$ = "  #####        ##.####   ##.####  ##.##     ##.###"
        FOR J = 1 TO 20
                READ OZ(J)
        NEXT J
        FOR J = 1 TO 20
                READ FS(J)
        NEXT J
        FOR J = 1 TO 20
                READ ACTS(J)
        NEXT J
END SUB

